pytilities.aop.aopmeta — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »

# pytilities.aop.aopmeta

class `pytilities.aop.aopmeta.` `AOPMeta`(name, bases, dictionary)

  Follows advice rules as described by Advisor

  `__delattr__`(obj, name)
  `__getattribute__`(obj, name)
  `__init__`(name, bases, dictionary)
  `__setattr__`(obj, name, value)
  `_delattr`(obj, base, name)
  `_getattr`(obj, base, name)
  `_setattr`(obj, base, name, value)

`pytilities.aop.aopmeta.` `_make_attrs`(base)

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »